@@ -27,6 +27,7 @@
 #include "goaprovider-priv.h"
 #include "goaoauth2provider.h"
 #include "goafoursquareprovider.h"
+#include "goaobjectskeletonutils.h"
 
 /**
  * GoaFoursquareProvider:
@@ -325,7 +326,6 @@ build_object (GoaProvider         *provider,
               GError             **error)
 {
   GoaAccount *account = NULL;
-  GoaMaps *maps = NULL;
   gboolean maps_enabled;
   gboolean ret = FALSE;
 
@@ -342,21 +342,8 @@ build_object (GoaProvider         *provider,
   account = goa_object_get_account (GOA_OBJECT (object));
 
   /* Maps */
-  maps = goa_object_get_maps (GOA_OBJECT (object));
   maps_enabled = g_key_file_get_boolean (key_file, group, "MapsEnabled", NULL);
-  if (maps_enabled)
-    {
-      if (maps == NULL)
-        {
-          maps = goa_maps_skeleton_new ();
-          goa_object_skeleton_set_maps (object, maps);
-        }
-    }
-  else
-    {
-      if (maps != NULL)
-        goa_object_skeleton_set_maps (object, NULL);
-    }
+  goa_object_skeleton_attach_maps (object, maps_enabled);
 
   if (just_added)
     {
@@ -371,7 +358,6 @@ build_object (GoaProvider         *provider,
 
  out:
   g_clear_object (&account);
-  g_clear_object (&maps);
   return ret;
 }
 
